@@ -1,6 +1,6 @@
 ;;; git-commit.el --- Edit Git commit messages  -*- lexical-binding:t; coding:utf-8 -*-
 
-;; Copyright (C) 2008-2024 The Magit Project Contributors
+;; Copyright (C) 2008-2025 The Magit Project Contributors
 
 ;; Author: Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
 ;;     Sebastian Wiesner <lunaryorn@gmail.com>
@@ -100,7 +100,9 @@
 
 ;;; Code:
 
+(require 'magit-git)
 (require 'magit-mode)
+(require 'magit-process)
 
 (require 'log-edit)
 (require 'ring)
@@ -192,12 +194,12 @@ The major mode configured here is turned on by the minor mode
 Also note that `git-commit-mode' (which see) is not a major-mode.")
 
 (defcustom git-commit-setup-hook
-  '(git-commit-ensure-comment-gap
-    git-commit-save-message
-    git-commit-setup-changelog-support
-    git-commit-turn-on-auto-fill
-    git-commit-propertize-diff
-    bug-reference-mode)
+  (list #'git-commit-ensure-comment-gap
+        #'git-commit-save-message
+        #'git-commit-setup-changelog-support
+        #'git-commit-turn-on-auto-fill
+        #'git-commit-propertize-diff
+        #'bug-reference-mode)
   "Hook run at the end of `git-commit-setup'."
   :group 'git-commit
   :type 'hook
@@ -243,7 +245,7 @@ commit, then the hook is not run at all."
   :type 'number)
 
 (defcustom git-commit-finish-query-functions
-  '(git-commit-check-style-conventions)
+  (list #'git-commit-check-style-conventions)
   "List of functions called to query before performing commit.
 
 The commit message buffer is current while the functions are
@@ -432,7 +434,7 @@ the redundant bindings, then set this to nil, before loading
 
 (require 'easymenu)
 (easy-menu-define git-commit-mode-menu git-commit-mode-map
-  "Git Commit Mode Menu"
+  "Git Commit Mode Menu."
   '("Commit"
     ["Previous" git-commit-prev-message t]
     ["Next" git-commit-next-message t]
@@ -649,8 +651,7 @@ the input isn't tacked to the comment."
 
 (defun git-commit-setup-changelog-support ()
   "Treat ChangeLog entries as unindented paragraphs."
-  (when (fboundp 'log-indent-fill-entry) ; New in Emacs 27.
-    (setq-local fill-paragraph-function #'log-indent-fill-entry))
+  (setq-local fill-paragraph-function #'log-edit-fill-entry)
   (setq-local fill-indent-according-to-mode t)
   (setq-local paragraph-start (concat paragraph-start "\\|\\*\\|(")))
 
@@ -739,7 +740,7 @@ conventions are checked."
 
 (defun git-commit-prev-message (arg)
   "Cycle backward through message history, after saving current message.
-With a numeric prefix ARG, go back ARG comments."
+With a numeric prefix ARG, go back ARG messages."
   (interactive "*p")
   (let ((len (ring-length log-edit-comment-ring)))
     (if (<= len 0)
@@ -767,7 +768,7 @@ With a numeric prefix ARG, go back ARG comments."
 
 (defun git-commit-next-message (arg)
   "Cycle forward through message history, after saving current message.
-With a numeric prefix ARG, go forward ARG comments."
+With a numeric prefix ARG, go forward ARG messages."
   (interactive "*p")
   (git-commit-prev-message (- arg)))
 
@@ -1047,10 +1048,10 @@ Added to `font-lock-extend-region-functions'."
 (defconst git-commit-font-lock-keywords-1
   '(;; Trailers
     (eval . `(,(git-commit--trailer-regexp)
-              (1 'git-commit-trailer-token)
-              (2 'git-commit-trailer-value)
-              (3 'git-commit-trailer-token)
-              (4 'git-commit-trailer-value)))
+              (1 'git-commit-trailer-token nil t)
+              (2 'git-commit-trailer-value nil t)
+              (3 'git-commit-trailer-token nil t)
+              (4 'git-commit-trailer-value nil t)))
     ;; Summary
     (eval . `(,(git-commit-summary-regexp)
               (1 'git-commit-summary)))
