@@ -1,6 +1,6 @@
 ;;; magit-wip.el --- Commit snapshots to work-in-progress refs  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2008-2024 The Magit Project Contributors
+;; Copyright (C) 2008-2025 The Magit Project Contributors
 
 ;; Author: Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
 ;; Maintainer: Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
@@ -317,11 +317,9 @@ commit message."
                        ;; Note: `update-index' is used instead of `add'
                        ;; because `add' will fail if a file is already
                        ;; deleted in the temporary index.
-                       (magit-call-git
-                        "update-index" "--add" "--remove"
-                        (and (magit-git-version>= "2.25.0")
-                             "--ignore-skip-worktree-entries")
-                        "--" files)
+                       (magit-call-git "update-index" "--add" "--remove"
+                                       "--ignore-skip-worktree-entries"
+                                       "--" files)
                      (magit-with-toplevel
                        (magit-call-git "add" "-u" ".")))
                    (magit-git-string "write-tree"))))
